@@ -1,3 +1,3 @@
 from ._measure_time import MeasureTime
 from .stat import gpustat, GpuStat
-from ._memory import get_process_memory, get_virtual_memory
+from ._stat_memory import get_process_memory, get_virtual_memory
